from __future__ import annotations

import uuid
from typing import Union

import click

from gcs_cli.helpers import record_print_result_message, requires_login
from gcs_cli.parsing import UUIDorUsername, globus_command
from gcs_cli.services.auth import get_client as get_auth_client
from gcs_cli.services.gcs import get_client


@globus_command("set-owner", short_help="Set the mapped collection owner")
@click.argument("COLLECTION_ID", type=click.UUID)
@click.argument("OWNER", type=UUIDorUsername())
@requires_login
def collection_set_owner(
    collection_id: uuid.UUID,
    owner: Union[str, uuid.UUID],
) -> None:
    """
    Update the owner on the mapped collection.

    This command may only be performed by the current endpoint owner or endpoint
    administrator.
    """
    client = get_client()
    owner_id = None

    if isinstance(owner, uuid.UUID):
        owner_id = str(owner)
    else:
        auth_client = get_auth_client()
        res = auth_client.get_identities(usernames=owner)["identities"]

        if not res:
            res = []
        for identity in res:
            if identity["username"] == owner:
                owner_id = identity["id"]
                break
        if not owner_id:
            click.echo("No such identity {}".format(owner), err=True)
            click.get_current_context().exit(1)

    doc = {"DATA_TYPE": "collection_owner#1.0.0", "identity_id": owner_id}

    res = client.put_collection_owner(collection_id, data=doc)
    record_print_result_message(res)
