from typing import Any

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    blackpearl_options,
    globus_command,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import BlackPearlStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import BLACKPEARL_CONNECTOR_ID


@globus_command("blackpearl")
@storage_gateway_create_and_update_params(create=True)
@blackpearl_options
@make_create_command
def blackpearl_create(
    *, s3_endpoint: str, blackpearl_access_id_file: str, **kwargs: Any
) -> StorageGatewayDocument:
    """Create a new BlackPearl Storage Gateway"""
    policies = BlackPearlStoragePolicies(
        s3_endpoint=s3_endpoint, bp_access_id_file=blackpearl_access_id_file
    )
    return StorageGatewayDocument(
        connector_id=BLACKPEARL_CONNECTOR_ID, policies=policies, **kwargs
    )
