from typing import (
    ClassVar,
    List,
    Optional,
    TYPE_CHECKING,
    Type,
)
import uuid

from .base import (
    Check,
    CheckInvoker,
    MissingPropertyCheck,
    ObjectIsNotNoneCheck,
    PropertyConstraintCheck,
)

from ..util import get_identity_map

if TYPE_CHECKING:
    from ..models.guest_collection import GuestCollection  # noqa: F401
    from ..typing.auth_documents import IdentityDocumentDict  # noqa: F401


class GuestCollectionCheck(CheckInvoker["GuestCollection"]):
    checkers: ClassVar[List[Type[Check["GuestCollection"]]]] = []
    object_name = "guest_collection"


@GuestCollectionCheck.checker
class GC01(ObjectIsNotNoneCheck["GuestCollection"]):
    ...


@GuestCollectionCheck.property_checker(property_name="owner_id")
class GC02(MissingPropertyCheck["GuestCollection"]):
    ...


@GuestCollectionCheck.property_checker(property_name="owner_id")
class GC03(PropertyConstraintCheck["GuestCollection"]):
    constraint_name = "invalid uuid"

    def value_is_ok(self, value: Optional["GuestCollection"]) -> bool:
        ok = True

        if value:
            if value.owner_id is not None:
                try:
                    uuid.UUID(value.owner_id)
                except Exception:
                    ok = False
        return ok


@GuestCollectionCheck.property_checker(property_name="owner_id")
class GC04(PropertyConstraintCheck["GuestCollection"]):
    constraint_name = "owner id valid state in Globus Auth"

    def value_is_ok(self, value: Optional["GuestCollection"]) -> bool:
        ok = True

        if value:
            if value.owner_id is not None:
                try:
                    idmap = get_identity_map()
                    identity = idmap[value.owner_id]
                    if identity["status"] == "closed":
                        ok = False
                    if identity["identity_type"] == "email":
                        ok = False
                except KeyError:
                    ok = False
        return ok


@GuestCollectionCheck.property_checker(property_name="credential")
class GC05(MissingPropertyCheck["GuestCollection"]):
    ...


@GuestCollectionCheck.property_checker(property_name="host_path")
class GC06(MissingPropertyCheck["GuestCollection"]):
    ...
