from typing import Any, Dict

from oauth2client import client as google_oauth

import globus.manager.api.errors as errors
import globus.manager.api.models as m
import globus.manager.api.schemas.connectors.google_cloud_storage  # noqa

from .oauth_credential_api import OAuthCredentialAPI


class GoogleCloudStorageConnector:
    CONNECTOR_ID = "56366b96-ac98-11e9-abac-9cb6d0d9fd63"
    DISPLAY_NAME = "Google Cloud Storage"
    model = m.GoogleCloudStorageGateway
    SCOPES = (
        "email "
        "profile "
        "https://www.googleapis.com/auth/devstorage.read_write "
        "https://www.googleapis.com/auth/cloudplatformprojects.readonly "
    )

    def __init__(self, app):
        self.oauth_credential_api = OAuthCredentialAPI(app)
        self.oauth_credential_api.add_connector(self.CONNECTOR_ID, self)

    def initiate_flow(
        self,
        storage_gateway: m.StorageGateway,
        authorized_identity: Dict[str, Any],
        **kwargs
    ) -> google_oauth.OAuth2WebServerFlow:
        flow = google_oauth.OAuth2WebServerFlow(
            client_id=storage_gateway.client_id,
            client_secret=storage_gateway.secret,
            scope=self.SCOPES,
            redirect_uri=self.callback_url,
            prompt="consent",
            **kwargs
        )
        if not getattr(storage_gateway, "allow_any_account", False):
            mapped_to = storage_gateway.map_identity(authorized_identity)
            if not mapped_to:
                raise errors.InvalidUserError()

            split_username = mapped_to.split("@")

            flow.params["login_hint"] = "@".join(split_username[0:2])
            flow.params["hd"] = split_username[1]

        return flow

    @property
    def callback_url(self) -> str:
        return self.oauth_credential_api.authcallback_google_url
