from __future__ import annotations


class Account:
    def __init__(
        self, username=None, storage_gateway_id=None, identity_id=None, **kwargs
    ):
        """
        Constructor for an account. It allows arbitrary keyword arguments so
        that callers can pass in a UserCredential document and it will extract
        the interesting values

        :param username:
            Connector-specific username
        :param storage_gateway_id:
            Storage Gateway this account is associated with.
        :param identity_id:
            Auth identity this account is associated with.
        """
        self.username = username
        self.storage_gateway_id = str(storage_gateway_id)
        self.identity_id = str(identity_id)

    def __eq__(self, other: object) -> bool:
        if not isinstance(other, Account):
            return False
        return (
            other.username == self.username
            and other.storage_gateway_id == self.storage_gateway_id
            and other.identity_id == self.identity_id
        )

    def __repr__(self):
        return "<Account {} {} {}>".format(
            self.username, self.storage_gateway_id, self.identity_id
        )
