import typing as t

import marshmallow as ma

from .data_type import Schema, data_type, data_type_schema
from .semantic_version import semantic_version_expression


@data_type("connector#1.0.0")
class Connector_1_0_0(Schema):
    """
    Connector information document
    """

    display_name = ma.fields.String(
        required=True,
        description="Friendly name of the connector",
        example="POSIX",
    )
    id = ma.fields.String(required=True, description="Unique id of this connector type")
    version = ma.fields.String(
        validate=[ma.validate.Regexp(semantic_version_expression)],
        description="Semantic version of this connector implementation",
    )


@data_type("connector#1.1.0")
class Connector_1_1_0(Connector_1_0_0):
    __doc__ = t.cast(str, Connector_1_0_0.__doc__) + (
        """
        Version 1.1.0 adds information about HA and BAA subscriptions.
    """
    )

    is_ha = ma.fields.Boolean(
        description="Subscription for this connector supports high assurance",
    )

    is_baa = ma.fields.Boolean(
        description="Subscription for this connector supports a BAA"
    )


Connector = data_type_schema.Connector
