"""
Connector-specific Policy Schemas

Each connector supplies its own specific policy schema types. There are
policies for collections, storage gateways, and user_credentials. Each of the
schema types should be decorated with the corresponding @collection_policy,
@storage_gateway_policy, or @user_credential_policy decorators to get them to
serialize and deserialize as the "policies" property of the collection,
storage_gateway, and user_credential schemas.
"""

from .activescale import (
    ActiveScaleCollectionPolicies,
    ActiveScaleStoragePolicies,
    ActiveScaleUserCredentialPolicies,
)
from .azure_blob import (
    AzureBlobCollectionPolicies,
    AzureBlobStoragePolicies,
    AzureBlobUserCredentialPolicies,
)
from .blackpearl import (
    BlackPearlCollectionPolicies,
    BlackPearlStoragePolicies,
    BlackPearlUserCredentialPolicies,
)
from .box import (
    BoxCollectionPolicies,
    BoxStoragePolicies,
    BoxUserCredentialPolicies,
)
from .ceph import (
    CephCollectionPolicies,
    CephStoragePolicies,
    CephUserCredentialPolicies,
)
from .dropbox import (
    DropboxCollectionPolicies,
    DropboxStoragePolicies,
    DropboxUserCredentialPolicies,
)
from .google_cloud_storage import (
    GoogleCloudStorageCollectionPolicies,
    GoogleCloudStoragePolicies,
    GoogleCloudStorageUserCredentialPolicies,
)
from .google_drive import (
    GoogleDriveCollectionPolicies,
    GoogleDriveStoragePolicies,
    GoogleDriveUserCredentialPolicies,
)
from .hpss import (
    HPSSCollectionPolicies,
    HPSSStoragePolicies,
    HPSSUserCredentialPolicies,
)
from .irods import (
    IrodsCollectionPolicies,
    IrodsStoragePolicies,
    IrodsUserCredentialPolicies,
)
from .onedrive import (
    OneDriveCollectionPolicies,
    OneDriveStoragePolicies,
    OneDriveUserCredentialPolicies,
)
from .posix import (
    PosixCollectionPolicies,
    PosixStoragePolicies,
    PosixUserCredentialPolicies,
)
from .posix_staging import (
    PosixStagingCollectionPolicies,
    PosixStagingStoragePolicies,
    PosixStagingUserCredentialPolicies,
)
from .s3 import (
    S3CollectionPolicies,
    S3StoragePolicies,
    S3UserCredentialPolicies,
)

__all__ = [
    "ActiveScaleStoragePolicies",
    "ActiveScaleCollectionPolicies",
    "ActiveScaleUserCredentialPolicies",
    "AzureBlobStoragePolicies",
    "AzureBlobCollectionPolicies",
    "AzureBlobUserCredentialPolicies",
    "BlackPearlStoragePolicies",
    "BlackPearlCollectionPolicies",
    "BlackPearlUserCredentialPolicies",
    "BoxStoragePolicies",
    "BoxCollectionPolicies",
    "BoxUserCredentialPolicies",
    "CephStoragePolicies",
    "CephCollectionPolicies",
    "CephUserCredentialPolicies",
    "DropboxStoragePolicies",
    "DropboxCollectionPolicies",
    "DropboxUserCredentialPolicies",
    "GoogleCloudStoragePolicies",
    "GoogleCloudStorageCollectionPolicies",
    "GoogleCloudStorageUserCredentialPolicies",
    "GoogleDriveStoragePolicies",
    "GoogleDriveCollectionPolicies",
    "GoogleDriveUserCredentialPolicies",
    "HPSSStoragePolicies",
    "HPSSCollectionPolicies",
    "HPSSUserCredentialPolicies",
    "IrodsStoragePolicies",
    "IrodsCollectionPolicies",
    "IrodsUserCredentialPolicies",
    "OneDriveStoragePolicies",
    "OneDriveCollectionPolicies",
    "OneDriveUserCredentialPolicies",
    "PosixStoragePolicies",
    "PosixCollectionPolicies",
    "PosixUserCredentialPolicies",
    "PosixStagingStoragePolicies",
    "PosixStagingCollectionPolicies",
    "PosixStagingUserCredentialPolicies",
    "S3StoragePolicies",
    "S3CollectionPolicies",
    "S3UserCredentialPolicies",
]
