import click

from gcs_cli.parsing.command_decorator import globus_command


@globus_command(
    name="update",
    short_help="Update the OIDC configuration for this endpoint.",
    disable_options=["format", "explicit_host"],
)
@click.option("--display-name", help="Display name for the OIDC server")
@click.option("--support-contact", help="Support contact name for the OIDC server")
@click.option(
    "--support-email",
    help="Support contact email address for the OIDC server",
)
@click.option(
    "--pam-service",
    "-p",
    help=(
        "Use this open to use a specific PAM service module for authentication. "
        "For GCS OIDC server only."
    ),
)
@click.option(
    "--certificate-path",
    metavar="PATH",
    help=(
        "Path to the certificate for the virtual host for the OIDC service. "
        "For GCS OIDC server only."
    ),
)
@click.option(
    "--certificate-chain-path",
    metavar="PATH",
    help=(
        "Path to the certificate chain for the virtual host for the OIDC service. "
        "For GCS OIDC server only."
    ),
)
@click.option(
    "--private-key-path",
    metavar="PATH",
    help=(
        "Path to the private key for the virtual host for the OIDC service. "
        "For GCS OIDC server only."
    ),
)
@click.option(
    "--client-id",
    metavar="CLIENT-ID",
    help=(
        "Client ID that Globus will use to authenticate with your OIDC server. "
        "For OIDC registration only."
    ),
)
@click.option(
    "--client-secret",
    metavar="SECRET",
    help=(
        "Client secret that Globus will use to authenticate with your OIDC server. "
        "For OIDC registration only."
    ),
)
@click.pass_context
def oidc_update(
    ctx,
    display_name,
    support_contact,
    support_email,
    pam_service,
    certificate_path,
    certificate_chain_path,
    private_key_path,
    client_id,
    client_secret,
) -> None:
    """
    Update the OIDC configuration for the local endpoint
    """
    from .oidc_update import oidc_update as ou

    ou(
        ctx,
        display_name,
        support_contact,
        support_email,
        pam_service,
        certificate_path,
        certificate_chain_path,
        private_key_path,
        client_id,
        client_secret,
    )
