from __future__ import annotations

import ipaddress
import typing as t

import click

T = t.TypeVar("T", bound=ipaddress._IPAddressBase)


def _IpAddressParamType(cls: t.Type[T]) -> t.Type[click.ParamType]:
    class _IpAddressParamType(click.ParamType):
        name = "ip_address"
        address_type: t.Type[T] = cls

        def convert(self, value, param, ctx):
            value = super().convert(value, param, ctx)

            if value:
                try:
                    ip_value = ipaddress.ip_address(value)
                    if isinstance(ip_value, self.address_type):
                        return ip_value
                except ValueError:
                    pass
                self.fail(f"Invalid address {value}")
            return value

        def __repr__(self):
            return "IP_ADDRESS"

    return _IpAddressParamType


IPv4AddressParamType = _IpAddressParamType(ipaddress.IPv4Address)
IPv6AddressParamType = _IpAddressParamType(ipaddress.IPv6Address)
IPAddressParamType = _IpAddressParamType(ipaddress._IPAddressBase)
