"""Remove collection_policies column and add domain unique constraint

Revision ID: 32a33d51c6d7
Revises: 75642f3dcaf3
Create Date: 2020-01-22 14:54:02.614000

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '32a33d51c6d7'
down_revision = '75642f3dcaf3'
branch_labels = None
depends_on = None


def upgrade():
    op.execute('PRAGMA foreign_keys = OFF')
    op.execute("PRAGMA legacy_alter_table=ON")

    op.rename_table('collection', 'collection_old')
    # Drop collection_policies column and add domain unique constraint
    op.create_table('collection',
        sa.Column('id', sa.TEXT(), nullable=False),
        sa.Column('path', sa.TEXT(), nullable=False),
        sa.Column('domain', sa.TEXT(), nullable=False, unique=True),
        sa.Column('user_credential_id', sa.TEXT(), nullable=True),
        sa.Column('storage_gateway_id', sa.TEXT(), nullable=False),
        sa.ForeignKeyConstraint(
            ['id'],
            ['configuration_object.id'],
            name='col_id'),
        sa.ForeignKeyConstraint(
            ['storage_gateway_id'],
            ['storage_gateway.id'], ),
        sa.ForeignKeyConstraint(
            ['user_credential_id'],
            ['user_credential.id'], ),
        sa.PrimaryKeyConstraint('id')
    )
    # Insert data---will break things :(
    op.execute(
        r"""
        INSERT INTO collection (
            id,
            path,
            domain,
            user_credential_id,
            storage_gateway_id)
        SELECT
            col.id,
            col.path,
            col.domain,
            col.user_credential_id,
            col.storage_gateway_id
        FROM collection_old as col
        """)
    # Drop collections_old table
    op.drop_table('collection_old')


def downgrade():
    raise RuntimeError("downgrade migration not implemented")
